View

Enum View 

pub enum View<'a> {
    Builtin(Builtin),
    Array(Box<View<'a>>, usize),
    Slice(Box<View<'a>>),
    Struct(ViewStruct<'a>),
    Enum(ViewEnum<'a>),
    RecUse(usize),
    RecNew(usize, Box<View<'a>>),
}
Available on crate feature schema only.

Variants



Builtin(Builtin)



Array(Box<View<'a>>, usize)



Slice(Box<View<'a>>)



Struct(ViewStruct<'a>)



Enum(ViewEnum<'a>)



RecUse(usize)



RecNew(usize, Box<View<'a>>)

Implementations

Source

impl View<'static>

pub fn new<'a, T: Wire<'a>>() -> View<'static>

Source

impl View<'_>

pub fn simplify(&self) -> View<'static>

Simplifies a view preserving wire compatibility.

Performs the following simplifications:

  • Remove field names and use empty names for variants
  • [x; 0] becomes ()
  • [x; 1] becomes x
  • [[x; n]; m] becomes [x; n * m]
  • [{}; 2+] becomes {}
  • (xs.. (ys..) zs..) becomes (xs.. ys.. zs..)
  • (xs.. {} zs..) becomes {}
  • (xs.. ys.. zs..) becomes (xs.. [y; n] zs..) if ys.. is n times y
  • (x) becomes x
  • {xs.. =t:{} zs..} becomes {xs.. zs..}
  • {xs..} becomes {ys..} where ys.. is xs.. sorted by tags
  • <n>:x (resp <n>) becomes <k>:x (resp. <k>) with k the number of recursion binders from the root
pub fn simplify_struct(xs: &ViewStruct<'_>) -> View<'static>

pub fn validate(&self, data: &[u8]) -> Result<(), Error>

Validates that serialized data matches the view.

This function requires a global lock.